@@ -804,7 +804,8 @@ static void krb5_resolve_callback(void *private_data, struct fo_server *server)
                                                  NULL);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE,
-                  "write_krb5info_file failed, authentication might fail.\n");
+                  "write to %s/kdcinfo.%s failed, authentication might fail.\n",
+                  PUBCONF_PATH, krb5_service->realm);
         }
     }
 }
