@@ -60,11 +60,13 @@ OV_USER1 = dict(name='ov_user1', passwd='x', uid=10010, gid=20010,
                 dir='/home/ov/user1',
                 shell='/bin/ov_user1_shell')
 
-ALT_USER1 = dict(name='altuser1', passwd='x', uid=60001, gid=70001,
+ALT_USER1 = dict(name='alt_user1', passwd='x', uid=60001, gid=70001,
                  gecos='User for tests from alt files',
                  dir='/home/altuser1',
                  shell='/bin/bash')
 
+ALL_USERS = [CANARY, USER1, USER2, OV_USER1, ALT_USER1]
+
 CANARY_GR = dict(name='canary',
                  gid=300001,
                  mem=[])
@@ -94,7 +96,7 @@ def start_sssd():
     """Start sssd and add teardown for stopping it and removing state"""
     os.environ["SSS_FILES_PASSWD"] = os.environ["NSS_WRAPPER_PASSWD"]
     os.environ["SSS_FILES_GROUP"] = os.environ["NSS_WRAPPER_GROUP"]
-    if subprocess.call(["sssd", "-D", "-f"]) != 0:
+    if subprocess.call(["sssd", "-D", "--logger=files"]) != 0:
         raise Exception("sssd start failed")
 
 
@@ -149,6 +151,7 @@ def files_domain_only(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
     """).format(**locals())
     create_conf_fixture(request, conf)
     create_sssd_fixture(request)
@@ -178,6 +181,7 @@ def files_multiple_sources(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
         passwd_files = {passwd_list}
         group_files = {group_list}
         debug_level = 10
@@ -212,6 +216,7 @@ def files_multiple_sources_nocreate(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
         passwd_files = {passwd_list}
         group_files = {group_list}
         debug_level = 10
@@ -235,6 +240,7 @@ def proxy_to_files_domain_only(request):
         id_provider = proxy
         proxy_lib_name = files
         auth_provider = none
+        resolver_provider = none
     """).format(**locals())
     create_conf_fixture(request, conf)
     create_sssd_fixture(request)
@@ -266,6 +272,7 @@ def no_files_domain(request):
 
         [domain/disabled.files]
         id_provider = files
+        fallback_to_nss = False
     """).format(**locals())
     create_conf_fixture(request, conf)
     create_sssd_fixture(request)
@@ -304,6 +311,7 @@ def domain_resolution_order(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
     """).format(**locals())
     create_conf_fixture(request, conf)
     create_sssd_fixture(request)
@@ -320,6 +328,7 @@ def default_domain_suffix(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
     """).format(**locals())
     create_conf_fixture(request, conf)
     create_sssd_fixture(request)
@@ -335,6 +344,7 @@ def override_homedir_and_shell(request):
 
         [domain/files]
         id_provider = files
+        fallback_to_nss = False
         override_homedir = /test/bar
         override_shell = /bin/bar
 
@@ -364,21 +374,34 @@ def setup_pw_with_canary(passwd_ops_setup):
     return setup_pw_with_list(passwd_ops_setup, [CANARY])
 
 
-def setup_gr_with_list(grp_ops, group_list):
+def add_group_members(pwd_ops, group):
+    members = {x['name']: x for x in ALL_USERS}
+    for member in group['mem']:
+        if pwd_ops.userexist(member):
+            continue
+
+        pwd_ops.useradd(**members[member])
+
+
+def setup_gr_with_list(pwd_ops, grp_ops, group_list):
     for group in group_list:
+        add_group_members(pwd_ops, group)
         grp_ops.groupadd(**group)
+
     ent.assert_group_by_name(CANARY_GR['name'], CANARY_GR)
     return grp_ops
 
 
 @pytest.fixture
-def add_group_with_canary(group_ops_setup):
-    return setup_gr_with_list(group_ops_setup, [GROUP1, CANARY_GR])
+def add_group_with_canary(passwd_ops_setup, group_ops_setup):
+    return setup_gr_with_list(
+        passwd_ops_setup, group_ops_setup, [GROUP1, CANARY_GR]
+    )
 
 
 @pytest.fixture
-def setup_gr_with_canary(group_ops_setup):
-    return setup_gr_with_list(group_ops_setup, [CANARY_GR])
+def setup_gr_with_canary(passwd_ops_setup, group_ops_setup):
+    return setup_gr_with_list(passwd_ops_setup, group_ops_setup, [CANARY_GR])
 
 
 def poll_canary(fn, name, threshold=20):
@@ -765,7 +788,9 @@ def test_gid_zero_does_not_resolve(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
-def test_add_remove_add_file_group(setup_gr_with_canary, files_domain_only):
+def test_add_remove_add_file_group(
+        setup_pw_with_canary, setup_gr_with_canary, files_domain_only
+):
     """
     Test that removing a group is detected and the group
     is removed from the sssd database. Similarly, an add
@@ -775,6 +800,7 @@ def test_add_remove_add_file_group(setup_gr_with_canary, files_domain_only):
     res, group = call_sssd_getgrnam(GROUP1["name"])
     assert res == NssReturnCode.NOTFOUND
 
+    add_group_members(setup_pw_with_canary, GROUP1)
     setup_gr_with_canary.groupadd(**GROUP1)
     check_group(GROUP1)
 
@@ -816,8 +842,10 @@ def test_mod_group_gid(add_group_with_canary, files_domain_only):
 
 
 @pytest.fixture
-def add_group_nomem_with_canary(group_ops_setup):
-    return setup_gr_with_list(group_ops_setup, [GROUP_NOMEM, CANARY_GR])
+def add_group_nomem_with_canary(passwd_ops_setup, group_ops_setup):
+    return setup_gr_with_list(
+        passwd_ops_setup, group_ops_setup, [GROUP_NOMEM, CANARY_GR]
+    )
 
 
 def test_getgrnam_no_members(add_group_nomem_with_canary, files_domain_only):
@@ -910,16 +938,19 @@ def test_getgrnam_ghost(setup_pw_with_canary,
                         setup_gr_with_canary,
                         files_domain_only):
     """
-    Test that a group with members while the members are not present
-    are added as ghosts. This is also what nss_files does, getgrnam would
-    return group members that do not exist as well.
+    Test that group if not found (and will be handled by nss_files) if there
+    are any ghost members.
     """
     user_and_group_setup(setup_pw_with_canary,
                          setup_gr_with_canary,
                          [],
                          [GROUP12],
                          False)
-    check_group(GROUP12)
+
+    time.sleep(1)
+    res, group = call_sssd_getgrnam(GROUP12["name"])
+    assert res == NssReturnCode.NOTFOUND
+
     for member in GROUP12['mem']:
         res, _ = call_sssd_getpwnam(member)
         assert res == NssReturnCode.NOTFOUND
@@ -931,7 +962,10 @@ def ghost_and_member_test(pw_ops, grp_ops, reverse):
                          [USER1],
                          [GROUP12],
                          reverse)
-    check_group(GROUP12)
+
+    time.sleep(1)
+    res, group = call_sssd_getgrnam(GROUP12["name"])
+    assert res == NssReturnCode.NOTFOUND
 
     # We checked that the group added has the same members as group12,
     # so both user1 and user2. Now check that user1 is a member of
@@ -1026,28 +1060,21 @@ def test_getgrnam_add_remove_ghosts(setup_pw_with_canary,
     modgroup = dict(GROUP_NOMEM)
     modgroup['mem'] = ['user1', 'user2']
     add_group_nomem_with_canary.groupmod(old_name=modgroup['name'], **modgroup)
-    check_group(modgroup)
+    time.sleep(1)
+    res, group = call_sssd_getgrnam(modgroup['name'])
+    assert res == sssd_id.NssReturnCode.NOTFOUND
 
     modgroup['mem'] = ['user2']
     add_group_nomem_with_canary.groupmod(old_name=modgroup['name'], **modgroup)
-    check_group(modgroup)
+    time.sleep(1)
+    res, group = call_sssd_getgrnam(modgroup['name'])
+    assert res == sssd_id.NssReturnCode.NOTFOUND
 
     res, _ = call_sssd_getpwnam('user1')
     assert res == NssReturnCode.NOTFOUND
     res, _ = call_sssd_getpwnam('user2')
     assert res == NssReturnCode.NOTFOUND
 
-    # Add this user and verify it's been added as a member
-    pwd_ops.useradd(**USER2)
-    # The negative cache might still have user2 from the previous request,
-    # flushing the caches might help to prevent a failed lookup after adding
-    # the user.
-    subprocess.call(["sss_cache", "-E"])
-    res, groups = sssd_id_sync('user2')
-    assert res == sssd_id.NssReturnCode.SUCCESS
-    assert len(groups) == 2
-    assert 'group_nomem' in groups
-
 
 def realloc_users(pwd_ops, num):
     # Intentionally not including the last one because
