@@ -21,10 +21,15 @@
 #ifndef _SSSCTL_H_
 #define _SSSCTL_H_
 
-#include "lib/sifp/sss_sifp.h"
-#include "lib/sifp/sss_sifp_dbus.h"
 #include "tools/common/sss_tools.h"
-#include "sbus/sssd_dbus.h"
+
+#define PRINT_IFP_WARNING(ret) do { \
+    if (ret == ERR_SBUS_UNKNOWN_SERVICE || ret == ERR_SBUS_NO_REPLY || ret == ETIMEDOUT) { \
+        fprintf(stderr, _("InfoPipe operation failed. Check that SSSD " \
+                "is running and the InfoPipe responder is enabled. Make sure " \
+                "'ifp' is listed in the 'services' option in sssd.conf.")); \
+    } \
+} while (0)
 
 enum sssctl_prompt_result {
     SSSCTL_PROMPT_YES,
@@ -47,29 +52,6 @@ bool sssctl_start_sssd(bool force);
 bool sssctl_stop_sssd(bool force);
 bool sssctl_restart_sssd(bool force);
 
-sss_sifp_error sssctl_sifp_init(struct sss_tool_ctx *tool_ctx,
-                                sss_sifp_ctx **_sifp);
-
-void _sssctl_sifp_error(sss_sifp_ctx *sifp,
-                        sss_sifp_error error,
-                        const char *message);
-
-#define sssctl_sifp_error(sifp, error, message) \
-    _sssctl_sifp_error(sifp, error, _(message))
-
-sss_sifp_error _sssctl_sifp_send(TALLOC_CTX *mem_ctx,
-                                 sss_sifp_ctx *sifp,
-                                 DBusMessage **_reply,
-                                 const char *path,
-                                 const char *iface,
-                                 const char *method,
-                                 int first_arg_type,
-                                 ...);
-
-#define sssctl_sifp_send(mem_ctx, sifp, reply, path, iface, method, ...) \
-    _sssctl_sifp_send(mem_ctx, sifp, reply, path, iface, method,         \
-                      ##__VA_ARGS__, DBUS_TYPE_INVALID);
-
 errno_t sssctl_systemd_start(void);
 errno_t sssctl_systemd_stop(void);
 errno_t sssctl_systemd_restart(void);
@@ -98,6 +80,10 @@ errno_t sssctl_cache_upgrade(struct sss_cmdline *cmdline,
                              struct sss_tool_ctx *tool_ctx,
                              void *pvt);
 
+errno_t sssctl_cache_expire(struct sss_cmdline *cmdline,
+                            struct sss_tool_ctx *tool_ctx,
+                            void *pvt);
+
 errno_t sssctl_logs_remove(struct sss_cmdline *cmdline,
                            struct sss_tool_ctx *tool_ctx,
                            void *pvt);
@@ -106,6 +92,10 @@ errno_t sssctl_logs_fetch(struct sss_cmdline *cmdline,
                           struct sss_tool_ctx *tool_ctx,
                           void *pvt);
 
+errno_t sssctl_debug_level(struct sss_cmdline *cmdline,
+                           struct sss_tool_ctx *tool_ctx,
+                           void *pvt);
+
 errno_t sssctl_user_show(struct sss_cmdline *cmdline,
                          struct sss_tool_ctx *tool_ctx,
                          void *pvt);
@@ -125,4 +115,16 @@ errno_t sssctl_config_check(struct sss_cmdline *cmdline,
 errno_t sssctl_user_checks(struct sss_cmdline *cmdline,
                            struct sss_tool_ctx *tool_ctx,
                            void *pvt);
+
+errno_t sssctl_access_report(struct sss_cmdline *cmdline,
+                             struct sss_tool_ctx *tool_ctx,
+                             void *pvt);
+
+errno_t sssctl_cert_show(struct sss_cmdline *cmdline,
+                         struct sss_tool_ctx *tool_ctx,
+                         void *pvt);
+
+errno_t sssctl_cert_map(struct sss_cmdline *cmdline,
+                        struct sss_tool_ctx *tool_ctx,
+                        void *pvt);
 #endif /* _SSSCTL_H_ */
