@@ -36,16 +36,21 @@
 
 #include "util/util.h"
 
+/* from debug_backtrace.h */
+void sss_debug_backtrace_init(void);
+void sss_debug_backtrace_vprintf(int level, const char *format, va_list ap);
+void sss_debug_backtrace_printf(int level, const char *format, ...);
+void sss_debug_backtrace_endmsg(int level);
+
 const char *debug_prg_name = "sssd";
 
 int debug_level = SSSDBG_UNRESOLVED;
 int debug_timestamps = SSSDBG_TIMESTAMP_UNRESOLVED;
 int debug_microseconds = SSSDBG_MICROSECONDS_UNRESOLVED;
-int debug_to_file = 0;
-int debug_to_stderr = 0;
-enum sss_logger_t sss_logger;
+enum sss_logger_t sss_logger = STDERR_LOGGER;
 const char *debug_log_file = "sssd";
-static FILE *debug_file;
+FILE *_sss_debug_file;
+uint64_t debug_chain_id;
 
 const char *sss_logger_str[] = {
         [STDERR_LOGGER] = "stderr",
@@ -56,48 +61,62 @@ const char *sss_logger_str[] = {
         NULL,
 };
 
-#ifdef WITH_JOURNALD
-#define JOURNALD_STR " journald,"
-#else
-#define JOURNALD_STR ""
-#endif
 
+/* this function isn't static to let access from debug-tests.c */
 void sss_set_logger(const char *logger)
 {
-    /* use old flags */
     if (logger == NULL) {
-        if (debug_to_stderr != 0) {
-            sss_logger = STDERR_LOGGER;
-        }
-        /* It is never described what should be used in case of
-         * debug_to_stderr == 1 && debug_to_file == 1. Because neither
-         * of binaries provide both command line arguments.
-         * Let files have higher priority.
-         */
-        if (debug_to_file != 0) {
-            sss_logger = FILES_LOGGER;
-        }
+        sss_logger = STDERR_LOGGER;
 #ifdef WITH_JOURNALD
-        if (debug_to_file == 0 && debug_to_stderr == 0) {
-            sss_logger = JOURNALD_LOGGER;
-        }
+        sss_logger = JOURNALD_LOGGER;
+#endif
+    } else if (strcmp(logger, "stderr") == 0) {
+        sss_logger = STDERR_LOGGER;
+    } else if (strcmp(logger, "files") == 0) {
+        sss_logger = FILES_LOGGER;
+#ifdef WITH_JOURNALD
+    } else if (strcmp(logger, "journald") == 0) {
+        sss_logger = JOURNALD_LOGGER;
 #endif
     } else {
-        if (strcmp(logger, "stderr") == 0) {
-            sss_logger = STDERR_LOGGER;
-        } else if (strcmp(logger, "files") == 0) {
-            sss_logger = FILES_LOGGER;
+        /* unexpected value */
+        fprintf(stderr, "Unexpected logger: %s\nExpected: ", logger);
+        fprintf(stderr, "%s", sss_logger_str[STDERR_LOGGER]);
+        fprintf(stderr, "|%s", sss_logger_str[FILES_LOGGER]);
 #ifdef WITH_JOURNALD
-        } else if (strcmp(logger, "journald") == 0) {
-            sss_logger = JOURNALD_LOGGER;
+        fprintf(stderr, "|%s", sss_logger_str[JOURNALD_LOGGER]);
 #endif
-        } else {
-            /* unexpected value */
-            fprintf(stderr, "Unexpected logger: %s\nExpected:%s stderr, "
-                            "files\n", logger, JOURNALD_STR);
+        fprintf(stderr, "\n");
+        sss_logger = STDERR_LOGGER;
+    }
+}
+
+static int _sss_open_debug_file(void)
+{
+    return open_debug_file_ex(NULL, NULL, true);
+}
+
+void _sss_debug_init(int dbg_lvl, const char *logger)
+{
+    if (dbg_lvl != SSSDBG_INVALID) {
+        debug_level = debug_convert_old_level(dbg_lvl);
+    } else {
+        debug_level = SSSDBG_UNRESOLVED;
+    }
+
+    sss_set_logger(logger);
+
+    /* if 'FILES_LOGGER' is requested then open log file, if it wasn't
+     * initialized before via set_debug_file_from_fd().
+     */
+    if ((sss_logger == FILES_LOGGER) && (_sss_debug_file == NULL)) {
+        if (_sss_open_debug_file() != 0) {
+            ERROR("Error opening log file, falling back to stderr\n");
             sss_logger = STDERR_LOGGER;
         }
     }
+
+    sss_debug_backtrace_init();
 }
 
 errno_t set_debug_file_from_fd(const int fd)
@@ -119,18 +138,18 @@ errno_t set_debug_file_from_fd(const int fd)
         return ret;
     }
 
-    debug_file = dummy;
+    _sss_debug_file = dummy;
 
     return EOK;
 }
 
 int get_fd_from_debug_file(void)
 {
-    if (debug_file == NULL) {
+    if (_sss_debug_file == NULL) {
         return STDERR_FILENO;
     }
 
-    return fileno(debug_file);
+    return fileno(_sss_debug_file);
 }
 
 int debug_convert_old_level(int old_level)
@@ -176,29 +195,6 @@ int debug_convert_old_level(int old_level)
     return new_level;
 }
 
-static void debug_fflush(void)
-{
-    fflush(debug_file ? debug_file : stderr);
-}
-
-static void debug_vprintf(const char *format, va_list ap)
-{
-    vfprintf(debug_file ? debug_file : stderr, format, ap);
-}
-
-static void debug_printf(const char *format, ...)
-                SSS_ATTRIBUTE_PRINTF(1, 2);
-
-static void debug_printf(const char *format, ...)
-{
-    va_list ap;
-
-    va_start(ap, format);
-
-    debug_vprintf(format, ap);
-
-    va_end(ap);
-}
 
 #ifdef WITH_JOURNALD
 static errno_t journal_send(const char *file,
@@ -271,14 +267,18 @@ void sss_vdebug_fn(const char *file,
                    const char *format,
                    va_list ap)
 {
+    static time_t last_time;
+    static char last_time_str[128];
     struct timeval tv;
-    struct tm *tm;
+    struct tm tm;
+    time_t t;
 
 #ifdef WITH_JOURNALD
     errno_t ret;
     va_list ap_fallback;
 
     if (sss_logger == JOURNALD_LOGGER) {
+        if (!DEBUG_IS_SET(level)) return; /* no debug backtrace with journald atm */
         /* If we are not outputting logs to files, we should be sending them
          * to journald.
          * NOTE: on modern systems, this is where stdout/stderr will end up
@@ -290,33 +290,50 @@ void sss_vdebug_fn(const char *file,
         ret = journal_send(file, line, function, level, format, ap);
         if (ret != EOK) {
             /* Emergency fallback, send to STDERR */
-            debug_vprintf(format, ap_fallback);
-            debug_fflush();
+            vfprintf(stderr, format, ap_fallback);
+            fflush(stderr);
         }
         va_end(ap_fallback);
         return;
     }
 #endif
 
-    if (debug_timestamps) {
-        gettimeofday(&tv, NULL);
-        tm = localtime(&tv.tv_sec);
-        debug_printf("(%d-%02d-%02d %2d:%02d:%02d",
-                     tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
-                     tm->tm_hour, tm->tm_min, tm->tm_sec);
-        if (debug_microseconds) {
-            debug_printf(":%.6ld", tv.tv_usec);
+    if (debug_timestamps == SSSDBG_TIMESTAMP_ENABLED) {
+        if (debug_microseconds == SSSDBG_MICROSECONDS_ENABLED) {
+            gettimeofday(&tv, NULL);
+            t = tv.tv_sec;
+        } else {
+            t = time(NULL);
+        }
+        if (t != last_time) {
+            last_time = t;
+            localtime_r(&t, &tm);
+            snprintf(last_time_str, sizeof(last_time_str),
+                     "(%d-%02d-%02d %2d:%02d:%02d",
+                     tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
+                     tm.tm_hour, tm.tm_min, tm.tm_sec);
+        }
+        if (debug_microseconds == SSSDBG_MICROSECONDS_ENABLED) {
+            sss_debug_backtrace_printf(level, "%s:%.6ld): ",
+                                       last_time_str, tv.tv_usec);
+        } else {
+            sss_debug_backtrace_printf(level, "%s): ", last_time_str);
         }
-        debug_printf("): ");
     }
 
-    debug_printf("[%s] [%s] (%#.4x): ", debug_prg_name, function, level);
+    sss_debug_backtrace_printf(level, "[%s] [%s] (%#.4x): ",
+                               debug_prg_name, function, level);
+
+    if (debug_chain_id > 0) {
+        sss_debug_backtrace_printf(level, "[RID#%lu] ", debug_chain_id);
+    }
+
+    sss_debug_backtrace_vprintf(level, format, ap);
 
-    debug_vprintf(format, ap);
     if (flags & APPEND_LINE_FEED) {
-        debug_printf("\n");
+        sss_debug_backtrace_printf(level, "\n");
     }
-    debug_fflush();
+    sss_debug_backtrace_endmsg(level);
 }
 
 void sss_debug_fn(const char *file,
@@ -332,32 +349,6 @@ void sss_debug_fn(const char *file,
     va_end(ap);
 }
 
-void ldb_debug_messages(void *context, enum ldb_debug_level level,
-                        const char *fmt, va_list ap)
-{
-    int loglevel = SSSDBG_UNRESOLVED;
-
-    switch(level) {
-    case LDB_DEBUG_FATAL:
-        loglevel = SSSDBG_FATAL_FAILURE;
-        break;
-    case LDB_DEBUG_ERROR:
-        loglevel = SSSDBG_CRIT_FAILURE;
-        break;
-    case LDB_DEBUG_WARNING:
-        loglevel = SSSDBG_TRACE_FUNC;
-        break;
-    case LDB_DEBUG_TRACE:
-        loglevel = SSSDBG_TRACE_LDB;
-        break;
-    }
-
-    if (DEBUG_IS_SET(loglevel)) {
-        sss_vdebug_fn(__FILE__, __LINE__, "ldb", loglevel, APPEND_LINE_FEED,
-                      fmt, ap);
-    }
-}
-
 /* In cases SSSD used to run as the root user, but runs as the SSSD user now,
  * we need to chown the log files
  */
@@ -419,7 +410,7 @@ int open_debug_file_ex(const char *filename, FILE **filep, bool want_cloexec)
         return ENOMEM;
     }
 
-    if (debug_file && !filep) fclose(debug_file);
+    if (_sss_debug_file && !filep) fclose(_sss_debug_file);
 
     old_umask = umask(SSS_DFL_UMASK);
     errno = 0;
@@ -445,7 +436,7 @@ int open_debug_file_ex(const char *filename, FILE **filep, bool want_cloexec)
     }
 
     if (filep == NULL) {
-        debug_file = f;
+        _sss_debug_file = f;
     } else {
         *filep = f;
     }
@@ -453,11 +444,6 @@ int open_debug_file_ex(const char *filename, FILE **filep, bool want_cloexec)
     return EOK;
 }
 
-int open_debug_file(void)
-{
-    return open_debug_file_ex(NULL, NULL, true);
-}
-
 int rotate_debug_files(void)
 {
     int ret;
@@ -465,10 +451,10 @@ int rotate_debug_files(void)
 
     if (sss_logger != FILES_LOGGER) return EOK;
 
-    if (debug_file != NULL) {
+    if (_sss_debug_file != NULL) {
         do {
             error = 0;
-            ret = fclose(debug_file);
+            ret = fclose(_sss_debug_file);
             if (ret != 0) {
                 error = errno;
             }
@@ -494,12 +480,12 @@ int rotate_debug_files(void)
         }
     }
 
-    debug_file = NULL;
+    _sss_debug_file = NULL;
 
-    return open_debug_file();
+    return _sss_open_debug_file();
 }
 
-void talloc_log_fn(const char *message)
+void _sss_talloc_log_fn(const char *message)
 {
     DEBUG(SSSDBG_FATAL_FAILURE, "%s\n", message);
 }
