@@ -35,7 +35,8 @@
 #include "util/tev_curl.h"
 
 #define TCURL_IOBUF_CHUNK   1024
-#define TCURL_IOBUF_MAX    16384
+/* This limit in the same one as KCM_REPLY_MAX */
+#define TCURL_IOBUF_MAX     10*1024*1024
 
 static bool global_is_curl_initialized;
 
@@ -96,7 +97,9 @@ static errno_t curl_code2errno(CURLcode crv)
         return ETIMEDOUT;
     case CURLE_SSL_ISSUER_ERROR:
     case CURLE_SSL_CACERT_BADFILE:
+#if LIBCURL_VERSION_NUM < 0x073e00
     case CURLE_SSL_CACERT:
+#endif
     case CURLE_SSL_CERTPROBLEM:
         return ERR_INVALID_CERT;
 
@@ -193,15 +196,13 @@ static void handle_curlmsg_done(CURLMsg *message)
         return;
     }
 
-    if (DEBUG_IS_SET(SSSDBG_TRACE_FUNC)) {
-        crv = curl_easy_getinfo(easy_handle, CURLINFO_EFFECTIVE_URL, &done_url);
-        if (crv != CURLE_OK) {
-            DEBUG(SSSDBG_MINOR_FAILURE, "Cannot get CURLINFO_EFFECTIVE_URL "
-                  "[%d]: %s\n", crv, curl_easy_strerror(crv));
-            /* not fatal since we need this only for debugging */
-        } else {
-            DEBUG(SSSDBG_TRACE_FUNC, "Handled %s\n", done_url);
-        }
+    crv = curl_easy_getinfo(easy_handle, CURLINFO_EFFECTIVE_URL, &done_url);
+    if (crv != CURLE_OK) {
+        DEBUG(SSSDBG_MINOR_FAILURE, "Cannot get CURLINFO_EFFECTIVE_URL "
+              "[%d]: %s\n", crv, curl_easy_strerror(crv));
+        /* not fatal since we need this only for debugging */
+    } else {
+        DEBUG(SSSDBG_TRACE_FUNC, "Handled %s\n", done_url);
     }
 
     crv = curl_easy_getinfo(easy_handle, CURLINFO_PRIVATE, (void *) &req);
@@ -411,6 +412,7 @@ static void check_fd_activity(struct tevent_context *ev,
 {
     struct tcurl_ctx *tctx = talloc_get_type(private_data, struct tcurl_ctx);
     check_curl_timeouts(tctx);
+    tctx->process_timer = NULL;
 }
 
 static int schedule_fd_processing(CURLM *multi,
@@ -567,12 +569,16 @@ static size_t tcurl_write_data(char *ptr,
     errno_t ret;
     size_t realsize = size * nmemb;
     struct sss_iobuf *outbuf;
+    char *envval;
 
     outbuf = talloc_get_type(userdata, struct sss_iobuf);
 
-    DEBUG(SSSDBG_TRACE_INTERNAL, "---> begin libcurl data\n");
-    DEBUG(SSSDBG_TRACE_INTERNAL, "%s\n", ptr);
-    DEBUG(SSSDBG_TRACE_INTERNAL, "<--- end libcurl data\n");
+    envval = getenv("SSS_KCM_LOG_PRIVATE_DATA");
+    if (envval != NULL && strcasecmp(envval, "YES") == 0) {
+        DEBUG(SSSDBG_TRACE_INTERNAL, "---> begin libcurl data\n");
+        DEBUG(SSSDBG_TRACE_INTERNAL, "%s\n", ptr);
+        DEBUG(SSSDBG_TRACE_INTERNAL, "<--- end libcurl data\n");
+    }
 
     ret = sss_iobuf_write_len(outbuf, (uint8_t *)ptr, realsize);
     if (ret != EOK) {
