@@ -145,6 +145,7 @@ enum sssd_errors {
     ERR_ID_OUTSIDE_RANGE,
     ERR_GID_DUPLICATED,
     ERR_MULTIPLE_ENTRIES,
+    ERR_UNSUPPORTED_RANGE_TYPE,
 
     /* DBUS Errors */
     ERR_SBUS_KILL_CONNECTION,
@@ -164,6 +165,8 @@ enum sssd_errors {
     ERR_INI_PARSE_FAILED,
     ERR_INI_ADD_SNIPPETS_FAILED,
 
+    ERR_TLS_HANDSHAKE_INTERRUPTED,
+
     ERR_LAST            /* ALWAYS LAST */
 };
 
